
#include "..\config.h"
#include "string.h"
#include "userDataProcess.h"

// Delay ms
// input: 0~65535 
void delayUs(INT16U us) {
    INT16U i=0;
	INT16U j=0;
    for(i=0; i<=us; i++) {
	    for(j=0; j<=16; j++);
	}
}

// Delay us
// input: 0~65535 
void delayMs(INT16U ms) {
    INT16U i=0;
    for(i=0; i<=ms; i++) {
	    delayUs(1000);
	}
}

// Initialize Key1 ~ Key4 PIN as input
void keyInit(void) {
    FIO2DIR &= ~KEY1;        // Set P2.10(KEY1) as input
	FIO2DIR &= ~KEY2;        // Set P2.11(KEY2) as input
    FIO2DIR &= ~KEY3;        // Set P2.12(KEY3) as input
    FIO2DIR &= ~KEY4;        // Set P2.13(KEY4) as input
}

// Set DB7~DB0 PIN as input or ourput
// direction=1 -> input   direction=0(or any other value non-1) -> output;   
void lcdDdataPinsDirectionSet(INT8U direction) {
    if(direction==1) {
		FIO0DIR2 = 0x00;      // Set P0.23~P0.16 as input
	}
	else {
		FIO0DIR2 = 0xFF;      // Set P0.23~P0.16 as output
	}
}

// Initialize LCD control PINs as output; RST, A0, RW, E;
void lcdPinInit(void) {
    FIO0DIR |= RST;                 // set P0.15(RST) as output
	FIO1DIR |= A0;                  // set P1.31(A0) as output
	FIO3DIR |= RW;                  // set P3.25(RW) as output
	FIO3DIR |= E;                   // set P3.26(E) as output

	lcdDdataPinsDirectionSet(0);    // set data pins as output
}

// Set RST level
// Input:   0->Low;  1->High
void setRST(INT8U RST_value) {
	if(RST_value == 0) {
		FIO0CLR = RST;	     // RST = 0
	}
	else {
		FIO0SET = RST;		 // RST = 1
	}
}

// Set A0 level
// Input:   0->Low;  1->High
void setA0(INT8U A0_value) {
	if(A0_value == 0) {
		FIO1CLR = A0;	     // A0 = 0
	}
	else {
		FIO1SET = A0;		 // A0 = 1
	}
}

// Set RW level
// Input:   0->Low;  1->High
void setRW(INT8U RW_value) {
	if(RW_value == 0) {
		FIO3CLR = RW;	     // RW = 0
	}
	else {
		FIO3SET = RW;		 // RW = 1
   }
}

// Set E level
// Input:   0->Low;  1->High
void setE(INT8U E_value) {
	if(E_value == 0) {
		FIO3CLR = E;	     // E = 0
	}
	else {
		FIO3SET = E;		 // E = 1
    }
}



// Write command
// Input:  Refer to Command Set	of Data Sheet
void writeComd(INT8U comd) {

    lcdDdataPinsDirectionSet(0);	      // DB7~DB0 as output
	
	setRW(0);  setA0(0);				  // Write instruction register

	FIO0PIN2 = comd;  // output command on P0.23~P0.16, as a 8bits bus
    delayUs(10);

	setE(1);   delayUs(5);
	setE(0);   delayUs(10);
}



// Wirte data,
// Input:  Refer to Data Sheet
void writeData(INT8U data) {
	
	lcdDdataPinsDirectionSet(0);	      // DB7~DB0 as output

	setRW(0);  setA0(1);				  // Write data register

	FIO0PIN2 = data;  // output data on P0.23~P0.16, as a 8bits bus
    delayUs(10);

	setE(1);   delayUs(5);
	setE(0);   delayUs(10);
}

// Initialize LCM controller IC, ST7567
void lcdInit(void) {

    setRST(0);
    delayMs(10);
	setRST(1);
	delayMs(10);		 // Reset ST7567

	writeComd(0xa2);    delayUs(100);   // bias=1/9, duty=1/65
	writeComd(0xa0);    delayUs(100);   // normal SEG direction
	writeComd(0xc0);    delayUs(100);	// normal COM direction
	writeComd(0xf8);    delayUs(100);	// set booster_(1) 
	writeComd(0x01);    delayUs(100);	// set booster_(2)	*5

	writeComd(0x27);    delayMs(100);	// Regulation Ratio 
	                                    // V0=9.0  RR=6.5 [RR2,RR1,RR0]=111 Ratio=0x27 EV=0x08
                                        // V0=8.7  RR=6   RR2RR1RR0=110 Ratio=0x26 EV=0x0c
                                        // V0=9.3  RR=6.5 RR2RR1RR0=111 Ratio=0x27 EV=0x0b

	writeComd(0x81);	delayUs(100);	// set EV_(1)
	writeComd(0x08);	delayUs(100);	// set EV_(2) : EV5~EV0=001000 (0x08) 

	writeComd(0x2f);	delayUs(100);	// power control
	writeComd(0xaf);	delayUs(100);	// display on
	
}

// **** fillScreen ****
// left -> right, up -> down, to fill screen
// this function just fill screen with simple data
void fillScreen(INT8U data) {
    INT16U i,j;
    for(j=0;j<8;j++) {
        writeComd(0xb0+j);   //set page address D0~D7
        writeComd(0x40);     //set start line
        writeComd(0x10);     //set column Address
        writeComd(0x00);
 
        for(i=0;i<132;i++){
            writeData(data);
        }
    } 
}

// **** cleanScreen ****
void cleanScreen(void)	{
    fillScreen(0x00);
}

// **** placeDot ****
// Place a dot at (x,y) on screen. (0,0) at the up left corner
// input:  x position (0~127)
//         y position (0~63)
// output: void
void placeDot(INT16U x, INT16U y) {
    if ( (x<=127) && (y<=63) ) {	    // protect overflow
        writeComd(0x10|(x>>4));	        // set x  (1)
	    writeComd(0x00|(x&0x0f));		// set x  (2) 
		writeComd(0xb0|(y/8));		    // set y; actually set current page
		writeData(1<<(y%8));            // write converted data
    }
}

void refreshScreen(INT8U *gData) {
    INT16U i,j;
    for(j=0;j<8;j++) {
        writeComd(0xb0+j);   //set page address D0~D7

        writeComd(0x10);     //set column Address
        writeComd(0x00);
 
        for(i=0;i<128;i++){
            writeData(gData[i+(j*128)]);
        }

    } 
}


INT8U graphic_11[1024]=	   // OD logo 1
{
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x80,
0x80,0x80,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x80,0xC0,0xE0,0xF0,0x78,0x3C,0x1E,0x0E,0x0F,0x07,0x87,0xC7,0xC3,0xC3,0xC3,0xC3,
0xC3,0xC3,0xC3,0xC7,0xC7,0xC7,0x8F,0x8E,0x1E,0x3C,0x78,0xF0,0xE0,0xC0,0x80,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xF0,0xFE,
0xFF,0x0F,0x03,0x00,0x00,0x00,0x00,0x00,0xE0,0xFC,0xFF,0xFF,0x7F,0x0F,0x01,0x01,
0x01,0x01,0x03,0x03,0xFF,0xFF,0xFF,0xFF,0x7F,0x00,0x00,0x00,0x03,0x0F,0xFF,0xFE,
0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x07,0x3F,
0xFF,0xF8,0xE0,0x80,0x00,0xC0,0xF8,0xFF,0xFF,0xFF,0xFF,0xE3,0xE0,0xE0,0xE0,0x70,
0x70,0x78,0x3C,0x3F,0x1F,0x0F,0x07,0x01,0x00,0x00,0x00,0x80,0xE0,0xF8,0xFF,0x3F,
0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x01,0x03,0x0F,0x0F,0x1E,0x3C,0x38,0x78,0x70,0x70,0xF0,0xE0,0xE0,0xE0,0xE0,
0xE0,0xE0,0xE0,0xF0,0x70,0x70,0x78,0x38,0x3C,0x1E,0x0F,0x0F,0x07,0x01,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x80,0xC0,0xE0,0x60,0x60,0x60,0xE0,0xC0,0x80,0x00,0xE0,0xE0,0x60,0x60,
0xE0,0xC0,0x00,0x60,0xE0,0xE0,0x60,0x00,0xE0,0xE0,0x60,0x60,0x60,0x00,0xE0,0xE0,
0xE0,0x80,0x00,0xE0,0xE0,0xE0,0x60,0x60,0xE0,0xE0,0xE0,0x60,0x60,0x00,0x00,0x00,
0x00,0xE0,0xE0,0x60,0x60,0x60,0xE0,0xC0,0x80,0x60,0xE0,0xE0,0x60,0x80,0xE0,0xE0,
0x60,0x60,0x60,0x00,0x00,0xE0,0xE0,0x60,0x60,0xE0,0xC0,0x00,0xE0,0xE0,0x00,0x00,
0x00,0x00,0x00,0xC0,0xE0,0x60,0xE0,0x00,0x00,0x20,0xE0,0xE0,0x80,0xC0,0xE0,0x60,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x07,0x0F,0x1F,0x18,0x18,0x18,0x1F,0x0F,0x07,0x00,0x1F,0x1F,0x06,0x0E,
0x1F,0x1B,0x10,0x18,0x1F,0x1F,0x18,0x00,0x1F,0x1F,0x1B,0x1B,0x1B,0x00,0x1F,0x1F,
0x01,0x07,0x0F,0x1F,0x1F,0x1F,0x00,0x00,0x1F,0x1F,0x1F,0x00,0x00,0x00,0x00,0x00,
0x00,0x1F,0x1F,0x18,0x18,0x18,0x1F,0x0F,0x07,0x18,0x1F,0x1F,0x18,0x0C,0x1D,0x1B,
0x1B,0x1F,0x1E,0x0C,0x00,0x1F,0x1F,0x06,0x06,0x07,0x03,0x00,0x1F,0x1F,0x18,0x18,
0x18,0x18,0x1E,0x1F,0x0F,0x0D,0x0F,0x1F,0x1C,0x00,0x00,0x1F,0x1F,0x1F,0x01,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
};


INT8U graphic_22[1024]=	   // OD logo 2
{
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x80,0xC0,0xC0,0xE0,0xE0,0xA0,0xA0,0xA0,0xA0,0xA0,0x20,
0x60,0xC0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xF0,0xFC,0x0E,0x03,0x01,0x00,0x01,0xFF,0xFF,0x0F,0x01,0x01,0x01,0x01,0x03,
0x03,0x0E,0xFF,0xFF,0xFE,0x3C,0xF0,0x00,0x00,0x00,0x80,0xF8,0xFC,0xFE,0x06,0xFE,
0xFE,0xFE,0x00,0xFC,0xFE,0xFE,0x86,0xFE,0xFE,0x7C,0x00,0xE0,0xFE,0xFE,0x0E,0xE0,
0xFE,0xFE,0x9E,0x86,0x86,0x02,0xF0,0xFE,0xFE,0xFE,0xFE,0xC0,0xFE,0xFE,0x0E,0x00,
0x84,0xFE,0xFE,0xFE,0x06,0x06,0x02,0x00,0x00,0xC0,0xFE,0xFE,0x3E,0x06,0xFE,0xFE,
0x3C,0x00,0xFE,0xFE,0x7E,0x00,0xF8,0xFE,0xFE,0x86,0x3E,0x3E,0x1C,0x80,0xFE,0xFE,
0x7E,0x06,0xFE,0xFE,0x3E,0x00,0xFE,0xFE,0xFE,0x00,0x00,0x00,0x00,0xC0,0xF8,0xFE,
0x3E,0xFE,0xFE,0x00,0x70,0xFE,0xFE,0xC0,0xE0,0x7C,0x3E,0x0E,0x02,0x00,0x00,0x00,
0x00,0x07,0x1F,0x70,0xC0,0x80,0x80,0xFF,0xFF,0xC7,0x80,0x80,0x80,0xC0,0xC0,0x60,
0x70,0x3C,0x9F,0xC7,0x70,0x3C,0x07,0x00,0x00,0x60,0xFF,0xFF,0xDF,0xC0,0xFF,0x7F,
0x1F,0xC0,0xFE,0xFF,0x7F,0x01,0xFF,0xFF,0xFF,0x00,0xFC,0xFF,0xFF,0x01,0xF8,0xFF,
0xFF,0xC3,0xC1,0xC1,0x00,0xFC,0xFF,0x1F,0x03,0xFF,0xFF,0xFF,0x3F,0x03,0x00,0xC0,
0xFF,0xFF,0x3F,0x00,0x00,0x00,0x00,0x00,0xF0,0xFF,0xFF,0xCF,0xC0,0xFF,0x7F,0x0F,
0xC0,0xFF,0xFF,0x07,0x00,0x78,0xFC,0xC1,0xF3,0xFF,0x7F,0x1E,0xC0,0xFF,0xFF,0x1F,
0x03,0x03,0x03,0x03,0xF0,0xFF,0xFF,0xCF,0xC0,0x80,0x00,0xF0,0xFE,0xFF,0x1F,0x0C,
0xFE,0xFF,0xFF,0x00,0x00,0xFF,0xFF,0x1F,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x03,0x02,0x06,0x06,0x06,0x06,0x06,0x06,0x02,
0x03,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
};

INT8U graphic_33[1024]=	   // OD logo 3
{
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xC0,0xC0,0xE0,
0xF0,0xF0,0xF0,0xF8,0xF8,0xFC,0xFC,0xFC,0xFE,0xFE,0x7E,0x7E,0x7E,0x7E,0x7E,0x7E,
0x7E,0x7E,0x7E,0xFE,0xFE,0xFE,0xFC,0xFC,0xFC,0xF8,0xF8,0xF8,0xF0,0xF0,0xC0,0xC0,
0xC0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x80,0xE0,0xF0,0xF0,0xFC,0xFC,0xFF,0xFF,0x7F,0x3F,0x1F,
0x1F,0x3F,0x1F,0x7F,0xFF,0xFF,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,0x7C,0x7C,
0x7C,0x7E,0x7E,0x7E,0x7E,0x7E,0x7E,0x7C,0xFC,0xF9,0xF9,0xF1,0xE3,0xC7,0x8F,0x1F,
0x3F,0x7F,0xFF,0xFE,0xFC,0xF8,0xE0,0xE0,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xE0,0xFC,0xFF,0xFF,0xFF,0xFF,0x7F,0x1F,0x0F,0x03,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xC0,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x07,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x07,0x7F,0xFF,0xFF,
0xFE,0xF8,0xF0,0xC1,0x03,0x07,0x0F,0x3F,0xFF,0xFF,0xFC,0xF0,0x80,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0x1F,0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0xC0,0xFF,0xFF,0xFF,0xFF,0xFF,0x0F,0x01,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xE7,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x01,0xFF,0xFF,0xFF,0xFF,0xFE,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0xF0,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xF8,0xFF,0xFF,
0xFF,0xFF,0xFF,0x3F,0x07,0x00,0xC0,0xF0,0xFE,0xFF,0xFF,0xFF,0xFF,0x1F,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x03,0x1F,0x7F,0xFF,0xFF,0xFF,0xFF,0xFE,0xF8,0xE0,0xC0,0x00,0x00,0x00,
0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x0F,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x80,0x80,0xC0,0xE0,0xF0,0xF8,0xFC,0xFE,0x7F,0x3F,0x1F,0x0F,
0x07,0x00,0xC0,0xC0,0xF8,0xFE,0xFF,0xFF,0xFF,0x7F,0x1F,0x07,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x07,0x0F,0x1F,0x3F,0x7F,0xFF,0xFE,0xFE,0xFC,
0xFC,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0x3E,0x7E,0x7E,0x7E,0x7E,0x7E,
0x7E,0x7E,0x3E,0x3F,0x9F,0x8F,0xCF,0xCF,0xC7,0xE3,0xE1,0xF0,0xF0,0xF0,0xFC,0xFC,
0xFF,0x7F,0x7F,0x3F,0x1F,0x0F,0x03,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x01,0x03,
0x03,0x07,0x0F,0x0F,0x0F,0x1F,0x1F,0x1F,0x1F,0x1F,0x3E,0x3F,0x3F,0x3F,0x3F,0x3F,
0x3F,0x3F,0x3F,0x3F,0x3F,0x3F,0x1F,0x1F,0x1F,0x0F,0x0F,0x0F,0x07,0x07,0x03,0x01,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
};



INT8U graphic_44[1024]=	   // bear
{
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xC0,0xC0,0xE0,0xE0,
0xE0,0xE0,0xE0,0xE0,0xE0,0xE0,0xE0,0xE0,0xE0,0xC0,0xC0,0xC0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0xC0,0xC0,0xC0,0xE0,0xE0,0xE0,0xE0,0xE0,
0xE0,0xE0,0xE0,0xE0,0xE0,0xE0,0xC0,0xC0,0xC0,0x80,0x80,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xF0,0xF8,0x1C,0x0C,
0x04,0x1C,0x1C,0xBC,0xF8,0xE0,0xE0,0xE0,0xF0,0xF0,0xF0,0xF0,0xF0,0xF0,0xF8,0xF8,
0xF0,0xF0,0xF0,0xF0,0xE0,0xE0,0xE0,0xF0,0xF8,0xBC,0x1C,0x0C,0x0C,0x1C,0x18,0xB8,
0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0xE0,0xF0,0xFC,0xFE,0xFE,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0x1F,0x1F,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,
0xFC,0xF0,0xF0,0xF0,0xFC,0xFE,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0x3F,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0xF8,0xF8,0xE0,
0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x06,0x0E,0xFC,
0xFC,0xFE,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0xF8,0xF8,0x8C,0x07,
0x07,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0x0F,0x00,0xC0,0x00,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0x1F,0x3F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0x1F,0x0F,0x00,0x00,0x0F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x7F,
0xFF,0xFF,0xFF,0xFF,0xFF,0xF9,0xF0,0xF0,0xE0,0xFD,0xFF,0x7F,0x7F,0x3F,0x3F,0x3F,
0x7F,0x7F,0xFF,0xF9,0xF0,0xE0,0xF0,0xF9,0xFF,0xFF,0xFF,0xFF,0xFF,0x7F,0x10,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x07,0x7F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0x0F,0x00,0xF0,0xFF,0xC0,0x00,0x1F,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0x1F,0x00,0xC0,0x00,0x03,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x7F,
0x00,0x00,0xFC,0x00,0x00,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x7F,0x3F,0x07,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xC0,0xE0,0xE0,
0xF1,0xE7,0xCF,0x9F,0x9F,0x3F,0x7F,0x7F,0x7F,0x7B,0x61,0xE3,0xE4,0xE0,0xE0,0xE0,
0xE4,0xE7,0xF3,0x79,0x7F,0x7F,0x3F,0x3F,0x9F,0x9F,0xCF,0xE7,0xF1,0xF0,0xE0,0xE0,
0xC0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x0F,0x1F,0x3F,0x7F,0x7F,0x7F,0x03,
0x00,0xF8,0xFF,0xFF,0xFF,0xE0,0x00,0x1F,0x3F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x07,
0x00,0xF0,0xFF,0xF8,0x00,0x03,0x3F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x7F,0x3F,0x00,
0xC0,0xFE,0xFF,0xA4,0x00,0x00,0x7F,0x7F,0x7F,0x3F,0x0F,0x07,0x01,0x00,0x00,0x00,
0x00,0x00,0x00,0xE0,0x70,0x30,0x18,0x1C,0x3E,0x3E,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0xFE,0x06,0x04,0x04,0x0C,0x1C,0x1C,0x9C,0x9C,
0x0C,0x0C,0x04,0x04,0x06,0xFE,0xFE,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0x1E,0x3C,0x1C,0x18,0x30,0x30,0xE0,0xC0,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x0E,
0x1F,0x3F,0x7F,0xFF,0xFF,0xFF,0xFF,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,0xFE,
0xFF,0x7F,0x3F,0x1F,0x0F,0x06,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x0F,0x08,0x10,0x20,0x60,0x60,0x30,0x38,0x1F,0x9F,0x8F,0x87,0xC7,
0xC7,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFC,0xFE,0xFE,0xFF,0xFE,0xFF,0xFF,0xFF,
0xFE,0xFF,0xFE,0xFE,0xFE,0xFE,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xC7,0x87,0x87,
0x8F,0x0F,0x1F,0x38,0x30,0x60,0x60,0x20,0x30,0x10,0x1F,0x07,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x01,0x03,0x07,0x0F,0x1F,0x3F,0x7F,0x7F,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x7F,0x3F,0x1F,0x0F,0x07,0x01,0x01,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0xF0,0xFC,0x0E,0x03,0x03,0x01,0x01,0x01,0x01,0x07,
0x0F,0xDF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,
0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0xFF,0x1F,0x07,0x03,0x03,
0x01,0x01,0x01,0x03,0x06,0x1C,0xF8,0xE0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x07,
0x07,0x1F,0x1F,0x0F,0x0F,0x07,0x03,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x07,0x0E,0x0C,0x18,0x10,0x10,0x10,0x18,0x18,
0x1E,0x1E,0x0F,0x0F,0x0F,0x0F,0x07,0x07,0x03,0x03,0x03,0x03,0x03,0x01,0x01,0x01,
0x03,0x03,0x03,0x03,0x07,0x07,0x07,0x0F,0x0F,0x0F,0x0F,0x1F,0x1E,0x1C,0x18,0x18,
0x10,0x10,0x18,0x08,0x0C,0x0E,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
};

INT8U graphic_55[1024]=	  // clock
{
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x80,0xC0,0xE0,0xE0,0xF0,0xF0,0xF8,0xF8,0xFC,0x7C,0x7C,0x7C,0x7E,0x3E,0x3E,0x3E,
0x3E,0x3E,0x3E,0x7E,0x7C,0x7C,0x7C,0xFC,0xF8,0xF8,0xF0,0xF0,0xE0,0xE0,0xC0,0x80,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xC0,0xF0,0xFC,0xFE,0xFF,
0x7F,0x3F,0x1F,0x8F,0xC7,0xE3,0xC1,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x03,0x07,0x0F,0x3F,0x7F,
0xFF,0xFE,0xFC,0xF0,0xC0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0xF0,0xFF,0xFF,0xFF,0xFF,0x1F,0x01,
0x00,0x00,0x00,0x00,0x01,0x03,0x07,0x0F,0x1F,0x3E,0x7C,0xF8,0xF8,0xF0,0xE0,0xC0,
0x80,0xC0,0xE0,0xE0,0xF0,0xF0,0x78,0x20,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x01,0x0F,0xFF,0xFF,0xFF,0xFF,0xF0,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0xFF,0xFF,0xFF,0xFF,0xF0,0x80,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x04,0x1E,0x1F,0x0F,0x0F,
0x0F,0x1F,0x3F,0x1D,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x80,0xF0,0xFF,0xFF,0xFF,0xFF,0x0F,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x0F,0x3F,0x7F,0xFF,
0xFE,0xFC,0xF0,0xE0,0xC0,0xC0,0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xC0,0xE0,0xF0,0xFC,0xFE,
0xFF,0x7F,0x3F,0x0F,0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x01,0x03,0x07,0x07,0x0F,0x0F,0x1F,0x1F,0x3F,0x3E,0x3E,0x3E,0x7C,0x7C,0x7C,0x7C,
0x7C,0x7C,0x7C,0x7C,0x3E,0x3E,0x3E,0x3F,0x1F,0x1F,0x0F,0x0F,0x07,0x07,0x03,0x01,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00
};


INT8U graphic_66[1024]=  // bird
{
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0x80,0x40,0xC0,0x40,0x60,0x60,0xA0,
0x60,0xE0,0x20,0x20,0x40,0x80,0x40,0xC0,0x80,0x80,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x80,0x60,0x50,0x78,0x08,0xEC,0xC4,0x66,0x26,0x26,0x36,0x26,0xE3,0xC3,0x03,
0x03,0x03,0x12,0xBC,0xFC,0x60,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x80,0x40,0x60,0x10,0x3C,0x24,0x06,0x07,0x75,0x71,0x78,0xFB,0xF9,0x64,0x20,0x08,
0x03,0x01,0x00,0x00,0x08,0x0F,0x0C,0x02,0x01,0x00,0xC1,0x75,0x63,0x32,0x0E,0x06,
0x04,0x08,0x0C,0x00,0x08,0x10,0x10,0x10,0x10,0x30,0x30,0x30,0x20,0x20,0x20,0x20,
0x20,0x20,0x20,0x20,0x30,0x30,0x30,0x10,0x10,0x18,0x08,0x08,0x0C,0x04,0x06,0x03,
0x03,0x01,0x01,0x07,0x80,0x82,0x82,0xC2,0xC2,0x66,0x6C,0x20,0x29,0x28,0x19,0x13,
0x0C,0x0C,0x06,0x02,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x06,0x07,
0x06,0x02,0x03,0x01,0x07,0x05,0x07,0x0F,0x04,0x04,0x06,0x9B,0xD8,0xF4,0x44,0x42,
0xC2,0x82,0x80,0x00,0x04,0x00,0x08,0x00,0x10,0x00,0x20,0x20,0x40,0x40,0x00,0x84,
0x1E,0x92,0xE2,0xF2,0xC8,0xE4,0x24,0x16,0xD2,0x42,0x02,0x00,0x10,0x10,0x10,0x10,
0x30,0x08,0x08,0x10,0x10,0x10,0x20,0x28,0x68,0x64,0xF4,0x9C,0x1E,0x0E,0x06,0x06,
0x03,0x03,0x03,0x01,0x01,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x40,
0x20,0x20,0x20,0x18,0x10,0x2C,0x20,0x04,0x8A,0x02,0x4B,0x6B,0x0A,0x81,0x83,0xC2,
0xE6,0xB4,0xD5,0x41,0x63,0x62,0x62,0x26,0x24,0x14,0x3C,0x18,0x08,0x08,0x18,0x08,
0x18,0x18,0x18,0x18,0x08,0x18,0x19,0x0B,0x08,0x0E,0x0E,0x09,0x2D,0x74,0xCA,0x29,
0x11,0x19,0x09,0x01,0x09,0x00,0x00,0x20,0x42,0xC4,0xDF,0xFF,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x02,0x0F,0x04,
0x04,0x02,0x02,0x03,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x01,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x06,
0x04,0x08,0x18,0x20,0x20,0x61,0x42,0xC6,0x88,0x78,0x57,0x07,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xC0,0xC0,
0x80,0xC0,0x40,0x00,0xC0,0x40,0x40,0x40,0x40,0x00,0xC0,0xC0,0x00,0x00,0x00,0x00,
0x00,0x80,0xC0,0x40,0x40,0x00,0xC0,0x00,0x80,0xC0,0x40,0x40,0x80,0x00,0x00,0xC0,
0xC0,0x80,0x80,0xC0,0xC0,0x00,0xC0,0xC0,0x40,0x40,0x40,0x40,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x40,0x40,0xC0,0x40,0x40,0x00,0x00,0x80,0xC0,0x40,0x40,0xC0,
0x80,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x80,0x80,0xC0,0xC0,
0xC0,0xC0,0xE0,0x20,0xA0,0xC0,0xC0,0xC0,0x40,0xC0,0x80,0x80,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x03,0x06,0x01,
0x03,0x07,0x00,0x00,0x07,0x07,0x05,0x05,0x05,0x00,0x07,0x06,0x04,0x04,0x00,0x00,
0x00,0x03,0x03,0x04,0x08,0x0C,0x02,0x00,0x03,0x05,0x0C,0x0C,0x07,0x07,0x00,0x03,
0x07,0x03,0x07,0x05,0x04,0x00,0x07,0x0F,0x09,0x09,0x09,0x09,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x0F,0x00,0x00,0x00,0x00,0x07,0x0F,0x08,0x0C,0x07,
0x03,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x38,0xFA,0x83,0x01,0x00,0xC0,0xF0,
0xFF,0x7F,0x1F,0x07,0x01,0x00,0x81,0x81,0xE3,0xFF,0x7E,0x3E,0x09,0xC6,0x38,0x00,
0x00,0x3C,0x64,0x42,0x42,0x7C,0x38,0x00,0x7E,0x1E,0x12,0x32,0x6E,0x44,0x00,0x00,
0x00,0x7E,0x00,0x00,0x00,0x00,0x7E,0x7E,0x52,0x52,0x52,0x40,0x00,0x7E,0x0C,0x18,
0x30,0x7E,0x18,0x00,0x02,0x7E,0x7E,0x02,0x02,0x00,0x00,0x00,0x00,0x00,0x00,0x00,
0x00,0x3C,0x7E,0x42,0x42,0x64,0x3C,0x00,0x00,0x00,0x7C,0x46,0x00,0x00,0x00,0x2C,
0x4C,0x5A,0x52,0x76,0x64,0x00,0x7C,0x7E,0x12,0x12,0x1E,0x08,0x00,0x7E,0x78,0x40,
0x40,0x40,0x40,0x00,0x60,0x38,0x1E,0x1E,0x78,0x60,0x00,0x06,0x0C,0x78,0x7C,0x06,
0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x00,0x01,0x03,0x03,0x03,0x07,
0x07,0x07,0x05,0x05,0x05,0x05,0x05,0x05,0x04,0x06,0x02,0x03,0x01,0x00,0x00,0x00
};



